@@ -2,7 +2,7 @@
  * Mp3Splt -- Utility for mp3/ogg splitting without decoding
  *
  * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
- * Copyright (c) 2005-2011 Alexandru Munteanu - <io_fx@yahoo.fr>
+ * Copyright (c) 2005-2012 Alexandru Munteanu - <io_fx@yahoo.fr>
  *
  * http://mp3splt.sourceforge.net
  *
@@ -27,7 +27,7 @@
 #include "options_manager.h"
 
 int parse_silence_options(char *arg, float *th, int *gap,
-    int *nt, float *off, int *rm, float *min, float *min_track_length);
+    int *nt, float *off, int *rm, float *min, float *min_track_length, int *shots);
 int parse_query_arg(options *opt, const char *query);
 regex_options *parse_tags_from_fname_regex_options(const char *parameters, int *error);
 
